@@ -1,4 +1,4 @@
-/* $Id: er_help.c,v 1.41 2013/01/28 10:51:15 cgarcia Exp $
+/* $Id: er_help.c,v 1.41 2013-01-28 10:51:15 cgarcia Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2004 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/28 10:51:15 $
+ * $Date: 2013-01-28 10:51:15 $
  * $Revision: 1.41 $
- * $Name: esorex-3_10 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -161,8 +161,9 @@ if (f_env_active == TRUE)
 
    pt1 = strchr(env_par,'.');		/* get first '.' */
    pt2 = strrchr(env_par,'.');		/* get last '.' */
-   if ((pt1 != NULL) && (pt2 != NULL) && 
-       (pt1 < pt2)) ;		/* it's the a.b.c string - no variable defined */
+   if ((pt1 != NULL) && (pt2 != NULL) && (pt1 < pt2)) {
+       ;		/* it's the a.b.c string - no variable defined */
+   }
    else
       {
       char  tmp[512];
