@@ -109,17 +109,18 @@ int er_create_recipe_pafs
 
 	    /* Get PRO CATG of this product */
 	    procatg_proplist = cpl_propertylist_load(filename, 0);
-	    this_pro_catg = cpl_propertylist_get_string
-		(procatg_proplist, CPL_DFS_PRO_CATG);
+	    this_pro_catg = cpl_propertylist_get_string(procatg_proplist, CPL_DFS_PRO_CATG);
+
 	    if(this_pro_catg == NULL)
-		{
-		cpl_msg_error(er_func,"Could not get PRO CATG in file %s",
-			filename);
-		er_paf_config_delete(paf_configuration);
-		cpl_free(arcfile);
-		paf_err = cpl_error_get_code();
-		return paf_err;
-		}
+	    {
+	        cpl_msg_error(er_func,"Could not get PRO CATG in file %s",
+	                      filename);
+	        er_paf_config_delete(paf_configuration);
+	        cpl_free(arcfile);
+	        paf_err = cpl_error_get_code();
+	        return paf_err;
+	    }
+
 	    ++idx_paf;
 	    cpl_msg_debug(er_func, "Product with PRO CATG=%s", this_pro_catg);
 	    cpl_msg_indent_more();
@@ -132,19 +133,29 @@ int er_create_recipe_pafs
 		int next;
 
 		cpl_msg_debug(er_func, "Matched with regexp =%s", 
-			      config_item->pro_catg_regexp);
+		              config_item->pro_catg_regexp);
+
+		/*
+		 *  Try to get ARCFILE from the product itself. If it is not present
+		 *  fall back to retrieving it from the first raw file in the frame
+		 *  set.
+		 */
+
+		arcfile = cpl_strdup(cpl_propertylist_get_string(procatg_proplist,
+		                                                 "ESO PRO ANCESTOR"));
 		
-                /* Read the ARCFILE keyword from the first raw file */
-                if(arcfile == NULL)
-                    {
-                    arcfile = er_paf_get_arcfile(frames);
-                    if(arcfile == NULL)
-                        {
-                        cpl_msg_error(er_func, "Could not read ARCFILE from raw frames");
-                        er_paf_config_delete(paf_configuration);
-                        return CPL_ERROR_DATA_NOT_FOUND;
-                        }
-                    }
+		if(arcfile == NULL)
+		{
+		    arcfile = er_paf_get_arcfile(frames);
+		    if(arcfile == NULL)
+		    {
+		        cpl_msg_error(er_func,
+		                      "Could not read ARCFILE information from "
+		                      "raw frames");
+		        er_paf_config_delete(paf_configuration);
+		        return CPL_ERROR_DATA_NOT_FOUND;
+		    }
+		}
 
 		/* Decide what to do depending on number of extensions */
 		next = cpl_frame_get_nextensions(frame);
@@ -404,6 +415,7 @@ struct er_paf_config * er_paf_read_config_file
 	{
 	char * line;
 	line = er_stringarray_get(file_buffer, iline);
+        cx_strstrip(line);
 	if (strcmp(line, "") != 0 && line[0] != '#' )
 	    er_stringarray_append(file_stripped, line);
 	}
@@ -613,36 +625,63 @@ cpl_propertylist* er_paf_fill_paf_proplist_multi_hdu
     }
 
 char * er_paf_get_arcfile(const cpl_frameset * frames)
-    {
+{
     const cpl_frame *  frame;
     char *             arcfile = NULL;
     cpl_propertylist * all_keywords;
     const char *       filename;
-    
+
     /* Loop into all the products */
-    frame = cpl_frameset_get_first_const(frames);
-    while (frame != NULL)
-	{
-	if (cpl_frame_get_group(frame) == CPL_FRAME_GROUP_RAW)
-	    {
-	    filename = cpl_frame_get_filename(frame);
-	    all_keywords = cpl_propertylist_load(filename, 0);
-	    if(all_keywords == NULL)
-		{
-		cpl_msg_error(er_func,"Could not read the main header of %s",
-			filename);
-		return NULL;
-		}
-	    arcfile = cpl_strdup
-	        (cpl_propertylist_get_string(all_keywords, "ARCFILE"));
-	    cpl_propertylist_delete(all_keywords);
-	    return arcfile;
-	    }
-	frame = cpl_frameset_get_next_const(frames);;
-	}
+
+    cpl_frameset_iterator *it = cpl_frameset_iterator_new(frames);
+
+    while ((frame = cpl_frameset_iterator_get_const(it)) != NULL)
+    {
+        if (cpl_frame_get_group(frame) == CPL_FRAME_GROUP_RAW)
+        {
+            filename = cpl_frame_get_filename(frame);
+            all_keywords = cpl_propertylist_load(filename, 0);
+            if(all_keywords == NULL)
+            {
+                cpl_frameset_iterator_delete(it);
+                cpl_msg_error(er_func,"Could not read the main header of %s",
+                              filename);
+                return NULL;
+            }
+
+            const char *_arcfile = cpl_propertylist_get_string(all_keywords,
+                                                               "ESO PRO ANCESTOR");
+
+            if (!_arcfile && !cpl_propertylist_has(all_keywords, "ESO PRO CATG")) {
+                _arcfile = cpl_propertylist_get_string(all_keywords, "ARCFILE");
+            }
+
+            if (!_arcfile) {
+                cpl_msg_error(er_func,"Could not get ARCFILE information from "
+                              "the main header of %s", filename);
+                cpl_frameset_iterator_delete(it);
+                cpl_propertylist_delete(all_keywords);
+                return NULL;
+            }
+
+            arcfile = cpl_strdup(_arcfile);
+
+            cpl_propertylist_delete(all_keywords);
+            cpl_frameset_iterator_delete(it);
+
+            return arcfile;
+        }
+
+        cpl_frameset_iterator_advance(it, 1);
+
+    }
+
+    cpl_frameset_iterator_delete(it);
+
     cpl_msg_error(er_func,"There are no RAW frames");
     return arcfile;
-    }
+
+}
 
 	    
 /**********************************************************************/
