@@ -527,24 +527,33 @@ return set;
  */
 /**********************************************************************/
 
-int upda_products (cpl_frameset * frameset)
- 
-
+inline static int
+_upda_products (cpl_frameset *frameset, unsigned int flags)
 {
-cpl_error_code reto;
+    cpl_error_code reto;
 
 
+    ER_TRACE(__func__);
 
-ER_TRACE(__func__);
+#if 0
+    reto = cpl_dfs_update_product_header(frameset);
+#else
 
+#if 0
+    unsigned int _flags = CPL_DFS_SIGNATURE_DATAMD5 | CPL_DFS_SIGNATURE_CHECKSUM;
+    reto = cpl_dfs_sign_products(frameset, _flags);
+#else
+    reto = cpl_dfs_sign_products(frameset, flags);
+#endif
 
-reto = cpl_dfs_update_product_header(frameset);
-if (reto != CPL_ERROR_NONE)
-   {
-   cpl_msg_error (er_func, "could not update the product header...");
-   }
+#endif
 
-return 0;
+    if (reto != CPL_ERROR_NONE)
+    {
+        cpl_msg_error (er_func, "could not update the product header...");
+    }
+
+    return 0;
 }
 
 /*
@@ -577,12 +586,13 @@ return 0;
  */
 /**********************************************************************/
 
-/* int move_products (char * plugin_name, */
-int move_products (cpl_frameset * frameset,
-                   char * output_directory,
-                   char * output_prefix,
-                   char * link_directory,
-                   int flag_noprefix, int flag_nolink, int flag_readonly)
+inline static int
+_move_products (cpl_frameset * frameset,
+                char * output_directory,
+                char * output_prefix,
+                char * link_directory,
+                unsigned int signature_mask,
+                int flag_noprefix, int flag_nolink, int flag_readonly)
 
 {
     cpl_frame *frame = NULL;       /* The current frame being processed */
@@ -682,7 +692,8 @@ int move_products (cpl_frameset * frameset,
 
     }
 
-    ii = upda_products(frameset);     /* MD5 errors ignored at the moment... */
+    /* MD5 errors ignored at the moment... */
+    ii = _upda_products(frameset, signature_mask);
     holdme = frameset;
 
 
@@ -973,9 +984,12 @@ int flag_time_plugin = 0,
     flag_create_config = 0, 
     flag_params = 0,
     flag_readonly = 0, 
-    flag_noprefix = 0, 
+    flag_noprefix = 0,
     f_val_unload_plugin = 1, 		/* default is TRUE */
     flag_nolink = 0;
+
+unsigned int signature_mask = CPL_DFS_SIGNATURE_DATAMD5 | CPL_DFS_SIGNATURE_CHECKSUM;
+
 unsigned long  uil;
 
 double plugin_time_start=0.0, plugin_time_end=0.0;
@@ -1415,9 +1429,25 @@ if (flag_plugin_found != 0)			/*  = TRUE */
 
    /* Check if we don't want to cleanup after processing (for debugging) */
 
-   p = cpl_parameterlist_find (caller_parameters,PACKAGE_RESOURCE ".unload-plugin");
-   f_val_unload_plugin = cpl_parameter_get_bool (p);
-   /* printf("f_val_unload_plugin = %d\n",f_val_unload_plugin); */
+   p = cpl_parameterlist_find(caller_parameters, PACKAGE_RESOURCE ".unload-plugin");
+   f_val_unload_plugin = cpl_parameter_get_bool(p);
+
+
+   /*
+    *  Set product signature bit mask
+    */
+
+   p = cpl_parameterlist_find(caller_parameters, PACKAGE_RESOURCE ".no-checksum");
+
+   if (cpl_parameter_get_bool(p) == TRUE) {
+       signature_mask &= ~CPL_DFS_SIGNATURE_CHECKSUM;
+   }
+
+   p = cpl_parameterlist_find(caller_parameters, PACKAGE_RESOURCE ".no-datamd5");
+
+   if (cpl_parameter_get_bool(p) == TRUE) {
+       signature_mask &= ~CPL_DFS_SIGNATURE_DATAMD5;
+   }
 
 
    /*
@@ -1425,26 +1455,29 @@ if (flag_plugin_found != 0)			/*  = TRUE */
     */
 
    if (e_code == 0)
-      {
-      plugin_func_exec = cpl_plugin_get_exec ((cpl_plugin *) trecipe);
+   {
+       plugin_func_exec = cpl_plugin_get_exec ((cpl_plugin *) trecipe);
 
-      if (plugin_func_exec != NULL)
-         {			/* We have a pointer, so run the plugin */
-         const char *recipe_name;
+       if (plugin_func_exec != NULL)
+       {			/* We have a pointer, so run the plugin */
+           const char *recipe_name;
 
-         recipe_name = cpl_plugin_get_name ((cpl_plugin *) trecipe);
-         cpl_msg_set_domain (recipe_name);
-         e_code = plugin_func_exec ((cpl_plugin *) trecipe);
-         cpl_msg_set_domain (PACKAGE);
-         if (e_code != 0)
-            {
-            cpl_msg_error (er_func,"Execution of recipe '%s' failed, status = %d",
-                           recipe_name,e_code);
-            }
-         }
-      else			/* NULL-pointer, so we simply set an error */
-         e_code = CPL_ERROR_INCOMPATIBLE_INPUT;
-      }
+           recipe_name = cpl_plugin_get_name ((cpl_plugin *) trecipe);
+           cpl_msg_set_domain (recipe_name);
+           e_code = plugin_func_exec ((cpl_plugin *) trecipe);
+           cpl_msg_set_domain (PACKAGE);
+           if (e_code != 0)
+           {
+               cpl_msg_error (er_func,"Execution of recipe '%s' failed, status = %d",
+                              recipe_name,e_code);
+           }
+       }
+       else
+       {
+           /* NULL-pointer, so we simply set an error */
+           e_code = CPL_ERROR_INCOMPATIBLE_INPUT;
+       }
+   }
 
    if (e_code == 0)			/* successful execution of recipe */
       {
@@ -1477,19 +1510,22 @@ if (flag_plugin_found != 0)			/*  = TRUE */
 
       /* Move all product files to output directory */
 
-      e_code = move_products (trecipe->frames, (char *)val_output_dir,
-                   (char *)val_output_mask,
-                   (char *)val_link_dir, flag_noprefix, 
-		   flag_nolink, flag_readonly);
+      e_code = _move_products(trecipe->frames, (char *)val_output_dir,
+                             (char *)val_output_mask, (char *)val_link_dir,
+                             signature_mask,
+                             flag_noprefix, flag_nolink, flag_readonly);
 
       if (e_code != 0) cpl_msg_error (er_func,
                         "An error occurred while trying to move the output products");
       }
 
    else			/* recipe failed, only get correct MD5 sum */
-      {			/* for all product files created anyway */
-      if (e_code != -99999) ii = upda_products (trecipe->frames);
-      }
+   {			/* for all product files created anyway */
+       if (e_code != -99999)
+       {
+           ii = _upda_products (trecipe->frames, signature_mask);
+       }
+   }
 
    /* Run PAF creation */
    p = cpl_parameterlist_find (caller_parameters,
